==> nextcloud-21.0.8p0.tgz: nextcloud/apps/dashboard/l10n/it.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Cruscotto",
    "Dashboard app" : "Cruscotto",
    "Show something" : "Mostra qualcosa",
    "Customize" : "Personalizza",
    "Edit widgets" : "Modifica widget",
    "Get more widgets from the App Store" : "Ottieni altri widget dal negozio delle applicazioni",
    "Change background image" : "Cambia l'immagine di sfondo",
    "Weather service" : "Servizio meteo",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
    "Weather data from Met.no" : "Dati meteo da Met.no",
    "geocoding with Nominatim" : "geocodifica conh Nominatim",
    "elevation data from OpenTopoData" : "dati di elevazione da OpenTopoData",
    "Weather" : "Meteo",
    "Status" : "Stato",
    "Good morning" : "Buongiorno",
    "Good morning, {name}" : "Buongiorno, {name}",
    "Good afternoon" : "Buon pomeriggio",
    "Good afternoon, {name}" : "Buon pomeriggio, {name}",
    "Good evening" : "Buona sera",
    "Good evening, {name}" : "Buona sera, {name}",
    "Hello" : "Ciao",
    "Hello, {name}" : "Ciao {name}",
    "Pick from Files" : "Scegli da File",
    "Default images" : "Immagini predefinite",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}",
    "Get more widgets from the app store" : "Ottieni altri widget dal negozio delle applicazioni",
    "Good night, {name}" : "Buona notte, {name}",
    "Good night" : "Buona notte",
    "Pick from files" : "Scegli da file"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.10.tgz: nextcloud/apps/dashboard/l10n/it.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Cruscotto",
    "Dashboard app" : "Cruscotto",
    "Customize" : "Personalizza",
    "Edit widgets" : "Modifica widget",
    "Get more widgets from the App Store" : "Ottieni altri widget dal negozio delle applicazioni",
    "Change background image" : "Cambia l'immagine di sfondo",
    "Weather service" : "Servizio meteo",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Per la tua riservatezza, i dati meteorologici sono richiesti dal tuo server Nextcloud per tuo conto, per cui il servizio meteo non riceve informazioni personali.",
    "Weather data from Met.no" : "Dati meteo da Met.no",
    "geocoding with Nominatim" : "geocodifica conh Nominatim",
    "elevation data from OpenTopoData" : "dati di elevazione da OpenTopoData",
    "Weather" : "Meteo",
    "Status" : "Stato",
    "Good morning" : "Buongiorno",
    "Good morning, {name}" : "Buongiorno, {name}",
    "Good afternoon" : "Buon pomeriggio",
    "Good afternoon, {name}" : "Buon pomeriggio, {name}",
    "Good evening" : "Buona sera",
    "Good evening, {name}" : "Buona sera, {name}",
    "Hello" : "Ciao",
    "Hello, {name}" : "Ciao {name}",
    "Pick from Files" : "Scegli da File",
    "Default images" : "Immagini predefinite",
    "Plain background" : "Sfondo semplice",
    "Insert from {productName}" : "Inserisci da {productName}",
    "Show something" : "Mostra qualcosa"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
